/*
   Copyright (C) 2002 Jason Stechschulte <stech@enormousplow.com>

	This program is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License.  This program is
	distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

#include "dialogs.h"


int begin(Window &window, Images &images, const string &DATADIR) {
	string fontName = "/usr/share/fonts/TTF/dejavu/DejaVuSans.ttf";
	TTF_Font *largeFont = NULL, *smallFont = NULL;
	int done = 0;
	SDL_Color gray = { 0xed, 0xed, 0xed, 0 };
	SDL_Event event;
	SDL_Surface *text;
	string message;
	int plane = 0;
	int fred = 0;
	int found = 0;

	SDL_Surface *play, *credits, *help, *quit;
	int playx = 100, playy = 220;
	int creditsx = 300, creditsy = 220;
	int helpx = 100, helpy = 290;
	int quitx = 300, quity = 290;

	// Find the airplane
	plane = images.find("plane");

	// Find the Fred
	fred = images.find("fred");

	// Open large font
	if(DEBUG) cout << "Opening large font" << endl;
	largeFont = TTF_OpenFont(fontName.c_str(), 48);
	if(largeFont == NULL) {
		cerr << "Couldn't load " << fontName << ": " << SDL_GetError() << endl;
		throw;
	}

	// Open small font
	if(DEBUG) cout << "Opening small font" << endl;
	smallFont = TTF_OpenFont(fontName.c_str(), 28);
	if(smallFont == NULL) {
		cerr << "Couldn't load font: " << SDL_GetError() << endl;
		throw;
	}

	while(!done && SDL_WaitEvent(&event)) {

		// Draw background
		window.drawBG();

		// Draw airplane
		window.drawIMG(images.sprite[plane].image, 400, 10,
						 	images.sprite[plane].image->w, images.sprite[plane].image->h);
	
		// Draw Fred
		window.drawIMG(images.sprite[fred].image, 360, 70,
						 	images.sprite[fred].image->w, images.sprite[fred].image->h);
	
		// Draw Fred again
		window.drawIMG(images.sprite[fred].image, 395, 30,
						 	images.sprite[fred].image->w, images.sprite[fred].image->h);
	
		// Draw Fred again
		window.drawIMG(images.sprite[fred+1].image, 265, 290,
						 	images.sprite[fred+1].image->w, images.sprite[fred+1].image->h);
	
		// Draw Fred again
		window.drawIMG(images.sprite[fred+1].image, 215, 320,
						 	images.sprite[fred+1].image->w, images.sprite[fred+1].image->h);

		// Start printing text
		message = "Free Fallin' Fred:";
		text = render(largeFont, message, gray);
		window.drawIMG(text, 20, 80, text->w, text->h);
		SDL_FreeSurface(text);

		message = "Open His Chute Or He'll Be Dead!";
		text = render(smallFont, message, gray);
		window.drawIMG(text, 20, 120, text->w, text->h);
		SDL_FreeSurface(text);

		message = "Play";
		play = render(smallFont, message, gray);
		window.drawIMG(play, playx, playy, play->w, play->h);

		message = "Credits";
		credits = render(smallFont, message, gray);
		window.drawIMG(credits, creditsx, creditsy, credits->w, credits->h);

		message = "Help";
		help = render(smallFont, message, gray);
		window.drawIMG(help, helpx, helpy, help->w, help->h);

		message = "Quit";
		quit = render(smallFont, message, gray);
		window.drawIMG(quit, quitx, quity, quit->w, quit->h);

		window.drawScene();

		if(event.type == SDL_QUIT) {
			done = 1;
		}
		else if(event.type == SDL_MOUSEBUTTONDOWN) {
			if(event.button.button == SDL_BUTTON_LEFT) {
				if(event.button.x > playx && event.button.x < playx + play->w
								 && event.button.y > playy && event.button.y < playy + play->h) {
					done = 2;
				}
				else if(event.button.x > quitx && event.button.x < quitx + quit->w
								 && event.button.y > quity && event.button.y < quity + quit->h) {
					done = 1;
				}
				else if(event.button.x > creditsx && event.button.x < creditsx + credits->w
								 && event.button.y > creditsy && event.button.y < creditsy + credits->h) {
					showCredits(window, smallFont, gray);
				}
				else if(event.button.x > helpx && event.button.x < helpx + help->w
								 && event.button.y > helpy && event.button.y < helpy + help->h) {
					showHelp(window, smallFont, gray);
				}
			}
		}
		else if(event.type == SDL_KEYDOWN) {
			if(event.key.keysym.sym == SDLK_q) {
				done = 1;
			}
			else if(event.key.keysym.sym == SDLK_p) {
				done = 2;
			}
			else if(event.key.keysym.sym == SDLK_c) {
				showCredits(window, smallFont, gray);
			}
			else if(event.key.keysym.sym == SDLK_h) {
				showHelp(window, smallFont, gray);
			}
		}
	}
	SDL_FreeSurface(play);
	SDL_FreeSurface(credits);
	SDL_FreeSurface(help);
	SDL_FreeSurface(quit);
	TTF_CloseFont(largeFont);
	TTF_CloseFont(smallFont);
	return (done == 1) ? 0 : 1;
}

void showCredits(Window &window, TTF_Font *font, SDL_Color gray) {
	int done = 0;
	SDL_Surface *text, *back;
	int backx, backy = 300;
	string message;
	SDL_Event event;

	while(!done && SDL_WaitEvent(&event)) {
		window.drawBG();

		message = "Credits:";
		text = TTF_RenderText_Solid(font, message.c_str(), gray);
		if(text == NULL) {
			cerr << "Couldn't render text: " << SDL_GetError() << endl;
			TTF_CloseFont(font);
			throw;
		}
		window.drawIMG(text, 20, 50, text->w, text->h);
		SDL_FreeSurface(text);

		message = "Programming: Jason Stechschulte";
		text = TTF_RenderText_Solid(font, message.c_str(), gray);
		if(text == NULL) {
			cerr << "Couldn't render text: " << SDL_GetError() << endl;
			TTF_CloseFont(font);
			throw;
		}
		window.drawIMG(text, 20, 100, text->w, text->h);
		SDL_FreeSurface(text);
	
		message = "Graphics: Jason Stechschulte";
		text = TTF_RenderText_Solid(font, message.c_str(), gray);
		if(text == NULL) {
			cerr << "Couldn't render text: " << SDL_GetError() << endl;
			TTF_CloseFont(font);
			throw;
		}
		window.drawIMG(text, 20, 150, text->w, text->h);
		SDL_FreeSurface(text);

		message = "Ulf Ekstrom";
		text = TTF_RenderText_Solid(font, message.c_str(), gray);
		if(text == NULL) {
			cerr << "Couldn't render text: " << SDL_GetError() << endl;
			TTF_CloseFont(font);
			throw;
		}
		window.drawIMG(text, 170, 180, text->w, text->h);
		SDL_FreeSurface(text);

		message = "Back";
		back = TTF_RenderText_Solid(font, message.c_str(), gray);
		if(back == NULL) {
			cerr << "Couldn't render text: " << SDL_GetError() << endl;
			TTF_CloseFont(font);
			throw;
		}
		backx = (window.getWidth() - back->w) / 2;
		window.drawIMG(back, backx, backy, back->w, back->h);

		window.drawScene();

		if(event.type == SDL_QUIT) {
			done = 1;
		}
		else if(event.type == SDL_MOUSEBUTTONDOWN) {
			if(event.button.button == SDL_BUTTON_LEFT) {
				if(event.button.x > backx && event.button.x < backx + back->w
								 && event.button.y > backy && event.button.y < backy + back->h) {
					done = 1;
				}
			}
		}
		else if(event.type == SDL_KEYDOWN) {
			if(event.key.keysym.sym == SDLK_b) {
				done = 1;
			}
		}
	}
	SDL_FreeSurface(back);
}

void showHelp(Window &window, TTF_Font *font, SDL_Color gray) {
	int done = 0;
	SDL_Surface *text, *back;
	int backx, backy = 300;
	string message;
	SDL_Event event;


	while(!done && SDL_WaitEvent(&event)) {
		window.drawBG();

		message = "Just click on the falling Fred";
		text = TTF_RenderText_Solid(font, message.c_str(), gray);
		if(text == NULL) {
			cerr << "Couldn't render text: " << SDL_GetError() << endl;
			TTF_CloseFont(font);
			throw;
		}
		window.drawIMG(text, 20, 50, text->w, text->h);
		SDL_FreeSurface(text);

		message = "to save his life.  Is it really";
		text = TTF_RenderText_Solid(font, message.c_str(), gray);
		if(text == NULL) {
			cerr << "Couldn't render text: " << SDL_GetError() << endl;
			TTF_CloseFont(font);
			throw;
		}
		window.drawIMG(text, 20, 100, text->w, text->h);
		SDL_FreeSurface(text);
	
		message = "that difficult?";
		text = TTF_RenderText_Solid(font, message.c_str(), gray);
		if(text == NULL) {
			cerr << "Couldn't render text: " << SDL_GetError() << endl;
			TTF_CloseFont(font);
			throw;
		}
		window.drawIMG(text, 20, 150, text->w, text->h);
		SDL_FreeSurface(text);

		message = "Back";
		back = TTF_RenderText_Solid(font, message.c_str(), gray);
		if(back == NULL) {
			cerr << "Couldn't render text: " << SDL_GetError() << endl;
			TTF_CloseFont(font);
			throw;
		}
		backx = (window.getWidth() - back->w) / 2;
		window.drawIMG(back, backx, backy, back->w, back->h);

		window.drawScene();

		if(event.type == SDL_QUIT) {
			done = 1;
		}
		else if(event.type == SDL_MOUSEBUTTONDOWN) {
			if(event.button.button == SDL_BUTTON_LEFT) {
				if(event.button.x > backx && event.button.x < backx + back->w
								 && event.button.y > backy && event.button.y < backy + back->h) {
					done = 1;
				}
			}
		}
		else if(event.type == SDL_KEYDOWN) {
			if(event.key.keysym.sym == SDLK_b) {
				done = 1;
			}
		}
	}
	SDL_FreeSurface(back);
}

int showEnd(Window &window, const string &DATADIR) {
	string fontName = "/usr/share/fonts/TTF/dejavu/DejaVuSans.ttf";
	TTF_Font *smallFont = NULL;
	int done = 0;
	SDL_Color gray = { 0xed, 0xed, 0xed, 0 };
	SDL_Event event;
	SDL_Surface *text;
	string message;

	SDL_Surface *play, *quit;
	int textx = 0, texty = 120;
	int playx = 150, playy = 220;
	int quitx = 350, quity = 220;

	// Open  font
	if(DEBUG) cout << "Opening font" << endl;
	smallFont = TTF_OpenFont(fontName.c_str(), 28);
	if(smallFont == NULL) {
		cerr << "Couldn't load font: " << SDL_GetError() << endl;
		throw;
	}

	while(!done && SDL_WaitEvent(&event)) {
		// Draw background
		window.drawBG();

		message = "Fred is now dead";
		text = render(smallFont, message, gray);
		textx = (window.getWidth() - text->w) / 2;
		window.drawIMG(text, textx, texty, text->w, text->h);
		SDL_FreeSurface(text);

		message = "Play";
		play = render(smallFont, message, gray);
		window.drawIMG(play, playx, playy, play->w, play->h);

		message = "Quit";
		quit = render(smallFont, message, gray);
		window.drawIMG(quit, quitx, quity, quit->w, quit->h);

		window.drawScene();

		if(event.type == SDL_QUIT) {
			done = 1;
		}
		else if(event.type == SDL_MOUSEBUTTONDOWN) {
			if(event.button.button == SDL_BUTTON_LEFT) {
				if(event.button.x > playx && event.button.x < playx + play->w
								 && event.button.y > playy && event.button.y < playy + play->h) {
					done = 2;
				}
				else if(event.button.x > quitx && event.button.x < quitx + quit->w
								 && event.button.y > quity && event.button.y < quity + quit->h) {
					done = 1;
				}
			}
		}
		else if(event.type == SDL_KEYDOWN) {
			if(event.key.keysym.sym == SDLK_q) {
				done = 1;
			}
			else if(event.key.keysym.sym == SDLK_p) {
				done = 2;
			}
		}
	}
	SDL_FreeSurface(play);
	SDL_FreeSurface(quit);
	TTF_CloseFont(smallFont);
	return (done == 1) ? 1 : 0;
}
